=====================================
 Aloe: Selenium Webdriver extensions
=====================================

`aloe_webdriver` provides utilities to help write Aloe_ BDD tests
that run in the browser using Selenium_ webdriver.

.. toctree::
    :maxdepth: 3

    basic
    forms
    other
    django
    writing-steps

Installing
==========

::

    pip install aloe_webdriver

.. include:: using.rst

History
=======

`Aloe-Webdriver` originally started life as the library
lettuce_webdriver_. This is a fork of that library for Aloe_.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _aloe: https://github.com/aloetesting/aloe
.. _aloe_django: https://github.com/aloetesting/aloe_django
.. _lettuce_webdriver: https://github.com/bbangert/lettuce_webdriver
.. _lettuce: http://lettuce.it/
.. _selenium: http://selenium-python.readthedocs.io/
